diff twisted/plugins/libervia_server.py @ 1522:a44f77559279

installation: moved from `setup.py` to `pyproject.toml`: - following backend change, installation is now using `pyproject.toml`, and legacy `setup.py` as well as other legacy files have been deleted/updated. - [hatch](https://hatch.pypa.io) is now used as main building tool. However, thanks to the use of standards, other tools can be used too. - `VERSION` file has been deleted, in favor or using directly `__version__`, in `libervia/web/__init__.py`. Version can be updated directly from Hatch - update .hgignore - several dependencies version bump, with code update to adapt to changes.
author Goffi <goffi@goffi.org>
date Wed, 07 Jun 2023 15:28:10 +0200
parents eb00d593801d
children
line wrap: on
line diff
--- a/twisted/plugins/libervia_server.py	Wed Jun 07 09:35:36 2023 +0200
+++ b/twisted/plugins/libervia_server.py	Wed Jun 07 15:28:10 2023 +0200
@@ -55,18 +55,18 @@
     import sys
 
     sys.stderr.write(
         """libervia.backend module version ({sat_version}) and {current_app} version ({current_version}) mismatch
 
-libervia.backend module is located at {sat_path}
-libervia module is located at {libervia_path}
+libervia.backend module is located at {libervia_backend_path}
+libervia module is located at {libervia_web_path}
 
 Please be sure to have the same version running
 """.format(
-            sat_version=libervia.backend.__version__,
+            libervia_backend_version=libervia.backend.__version__,
             current_app=C.APP_NAME,
             current_version=libervia.web.__version__,
-            sat_path=os.path.dirname(libervia.backend.__file__),
-            libervia_path=os.path.dirname(libervia.web.__file__),
+            libervia_backend_path=os.path.dirname(libervia.backend.__file__),
+            libervia_web_path=os.path.dirname(libervia.web.__file__),
         )
     )
     sys.stderr.flush()
@@ -160,7 +160,7 @@
     #      so here is the best place.
     from libervia.backend.core import log_config
 
-    log_config.sat_configure(C.LOG_BACKEND_TWISTED, C, backend_data=options)
+    log_config.libervia_configure(C.LOG_BACKEND_TWISTED, C, backend_data=options)
 
 
 class Options(usage.Options):
@@ -55,18 +55,18 @@
 
     sys.stderr.write(
-        """libervia.backend module version ({sat_version}) and {current_app} version ({current_version}) mismatch
+        """libervia.backend module version ({libervia_backend_version}) and {current_app} version ({current_version}) mismatch
 